Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1405)

Unified Diff: cc/resources/resource_provider.h

Issue 2735943002: cc: Clarify that color spaces are for raster (Closed)
Patch Set: Rebase (a few times) Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | cc/resources/resource_provider.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: cc/resources/resource_provider.h
diff --git a/cc/resources/resource_provider.h b/cc/resources/resource_provider.h
index d12767136fe72b43dcbc2ba3d8695b99e47a8182..89836b957fea94a47c61ec2b4b01dae560ba5c02 100644
--- a/cc/resources/resource_provider.h
+++ b/cc/resources/resource_provider.h
@@ -86,7 +86,7 @@ class CC_EXPORT ResourceProvider
size_t id_allocation_chunk_size,
bool delegated_sync_points_required,
bool use_gpu_memory_buffer_resources,
- bool enable_color_correct_rendering,
+ bool enable_color_correct_rasterization,
const BufferToTextureTargetMap& buffer_to_texture_target_map);
~ResourceProvider() override;
@@ -712,7 +712,7 @@ class CC_EXPORT ResourceProvider
gpu::gles2::GLES2Interface* ContextGL() const;
bool IsGLContextLost() const;
// Returns null if |settings_.enable_color_correct_rendering| is false.
sk_sp<SkColorSpace> GetResourceSkColorSpace(const Resource* resource) const;
// Holds const settings for the ResourceProvider. Never changed after init.
@@ -720,7 +720,7 @@ class CC_EXPORT ResourceProvider
Settings(ContextProvider* compositor_context_provider,
bool delegated_sync_points_required,
bool use_gpu_memory_buffer_resources,
- bool enable_color_correct_rendering);
+ bool enable_color_correct_rasterization);
int max_texture_size = 0;
bool use_texture_storage_ext = false;
@@ -732,7 +732,7 @@ class CC_EXPORT ResourceProvider
ResourceFormat yuv_highbit_resource_format = LUMINANCE_8;
ResourceFormat best_texture_format = RGBA_8888;
ResourceFormat best_render_buffer_format = RGBA_8888;
- bool enable_color_correct_rendering = false;
+ bool enable_color_correct_rasterization = false;
bool delegated_sync_points_required = false;
} const settings_;
« no previous file with comments | « no previous file | cc/resources/resource_provider.cc » ('j') | no next file with comments »
@@ -712,7 +712,7 @@ class CC_EXPORT ResourceProvider
gpu::gles2::GLES2Interface* ContextGL() const;
bool IsGLContextLost() const;
- // Returns null if |settings_.enable_color_correct_rendering| is false.
+ // Returns null if |settings_.enable_color_correct_rasterization| is false.
sk_sp<SkColorSpace> GetResourceSkColorSpace(const Resource* resource) const;
// Holds const settings for the ResourceProvider. Never changed after init.

Powered by Google App Engine
This is Rietveld 408576698